#
# spec file for package retro-gtk
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           retro-gtk
Version:        0.12.1
Release:        bp153.1.25
Summary:        Toolkit to write Gtk+3-based frontends to libretro
License:        GPL-3.0
Group:          System/GUI/GNOME
Url:            https://git.gnome.org/browse/retro-gtk
Source:         http://download.gnome.org/sources/retro-gtk/0.12/%{name}-%{version}.tar.xz
BuildRequires:  gobject-introspection-devel >= 0.6.7
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  vala
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libpulse-simple)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
retro-gtk wraps the libretro API for use in Gtk applications such as
GNOME Games.

%package -n libretro-gtk0
Summary:        Toolkit to write Gtk+3-based frontends to libretro
Group:          System/Libraries

%description -n libretro-gtk0
retro-gtk wraps the libretro API for use in Gtk applications such as
GNOME Games.
(libretro is an API specification implemented by some emulator
libraries like libretro-bsnes.)

%package -n typelib-1_0-Retro-0_12
Summary:        GObject introspection bindings for libretro-gtk
Group:          System/Libraries

%description -n typelib-1_0-Retro-0_12
retro-gtk wraps the libretro API for use in Gtk applications.
This subpackage contains the gobject bindings for the
libretro-gtk shared library.

%package devel
Summary:        Development files for retro-gtk, a Gtk+3 wrapper for libretro
Group:          Development/Languages/C and C++
Requires:       libretro-gtk0 = %{version}
Requires:       typelib-1_0-Retro-0_12 = %{version}

%description devel
retro-gtk wraps the libretro API for use in Gtk applications.
This subpackage contains the headers to make use of the libretro-gtk
library.

%prep
%setup -q

%build
%configure
make %{?_smp_mflags}

%install
make %{?_smp_mflags} DESTDIR=%{buildroot} install
find %{buildroot} -type f -name "*.la" -delete -print
# make install copies AUTHORS, COPYING et.al to doc/%%{name}
# we capture them using the %%doc macro
rm -rf %{buildroot}%{_datadir}/doc/%{name}

%post   -n libretro-gtk0 -p /sbin/ldconfig
%postun -n libretro-gtk0 -p /sbin/ldconfig

%files -n libretro-gtk0
%defattr(-,root,root)
%doc ChangeLog COPYING
%{_libdir}/libretro-gtk.so.*

%files -n typelib-1_0-Retro-0_12
%defattr(-,root,root)
%{_libdir}/girepository-1.0/Retro-0.12.typelib

%files devel
%defattr(-,root,root)
%{_bindir}/retro-demo
%{_datadir}/gir-1.0/Retro-0.12.gir
%{_datadir}/vala/vapi/retro-gtk-0.12.deps
%{_datadir}/vala/vapi/retro-gtk-0.12.vapi
%{_libdir}/pkgconfig/retro-gtk-0.12.pc
%{_libdir}/libretro-gtk.so
%{_includedir}/retro-gtk-0.12/

%changelog
* Tue Oct  3 2017 zaitor@opensuse.org
- Drop no longer used tar scm service, upstream releases tarballs
  now.
* Mon Oct  2 2017 aplazas@suse.com
- Update to version 0.12.1:
  + Core:
  - Fix a memory leak in the destructor.
  - Support partially setting memory regions.
  + CoreView: Reset inputs when losing focus.
* Mon Sep 11 2017 aplazas@suse.com
- Update to version 0.12.0:
  + CoreViewInputDevice: Don't log errors when 'view' is NULL.
  + GameInfo: Remove some free to avoid uselessly trying to free an
    already freed RetroGameInfo.
* Mon Sep  4 2017 aplazas@suse.com
- Update to version 0.11.92:
  + Core:
  - Remove the barely used system-info property.
  - Use Gdk.EventKey for keyboard inputs.
  - Make the init singal an error-throwing method.
  - Implement disk handling directly.
  + CoreView can be exposed as a joypad, a mouse or a pointer.
  + retro-demo: add pointer support from CoreView.
  + Make all error domains internal.
  + Make internal and port to C:
  - GameInfo.
  - Module.
  - SystemAvInfo.
  - SystemInfo.
  - most of Core.
  - keyboard keys.
  + Remove unused symbols:
  - DiskControl.
  - GamepadConfiguration.
  - GamepadButtonType.
  - Keyboard.
  - KeyboardState.
  - MemDesc.
  - MemoryDescriptor.
  - MemoryMap.
  - Mouse.
  - VirtualGamepad.
  - get_system_info ().
  - SNES specific memory types from MemoryType.
* Mon Jul 17 2017 aplazas@suse.com
- Update to version 0.11.4.1:
  + A demo application has been added, it allows to directly test
    the without the need of an external tool.
  + Loading games:
  - Add the set_medias(), load_medias() and set_current_media()
    methods to Core and load the given medias (if any) in
    Core.init().
  - Remove load_game() and prepare() Core methods from the
    public API as they are now used indirectly.
  - This should simplify loading games for the users of the
    library.
  + Logging:
  - Add the Core.log() signal which will emit a GLib compatible
    logging message with the Libretro core's name as the log
    domain.
  - Add retro_g_log() to simply handle Core.log() by outputing
    the logs in the expected unstructured GLib fashion.
  - Remove LogLevel, Log and FileStreamLog as they are now
    useless.
  + Add CoreView as a prototype of a single widget to handle most
    inputs and outputs of a core and use it in the demo.
  + Add CoreDescriptor.get_uri().
  + Make CairoDisplay.set_core() and Make PaPlayer.set_core()
    accept null.
  + Fix the transmission of keyboard events to the Libretro core.
  + Rotation and many methods of Core are ported to C.
- Rename subpackage typelib-1_0-Retro-0_10 to
  typelib-1_0-Retro-0_12 following upstream changes.
* Mon Mar 20 2017 dimstar@opensuse.org
- Update to version 0.10.0:
  + Save the expected ratio as DPI of the video frames.
  + Bugs fixed: bgo#769833, bgo#779924, bgo#779987.
* Mon Mar 13 2017 dimstar@opensuse.org
- Update to version 0.9.92:
  + Allow recursive iteration through Libretro cores of a
    directory.
- Drop _service: upstream publishes proper tarballs now.
- Drop libtool BuildRequires and no longer call autogen.sh: no
  longer needed since we use a botstrapped tarball.
* Tue Feb 28 2017 adrien.plazas@suse.com
- Update to version 0.9.91:
  + Deduplicate some documentation.
  + Add missing MouseId values.
  + Remove deprecated input device types.
  + Allow core descriptors to check the firmwares.
  + Add an helper method to core descriptors tocheck the supported
    MIME types.
  + Add a module iterator, allowing sync and async module browsing.
  + Remove the now useless foreach function to browse the modules.
  + Add methods to Core to handle standalone cores more easily.
  + Fix an integer division when computing the aspect ratio.
  + Add a script to update libretro.h.
- Remove retro-gtk-fix-build-deps.patch as it already is in the new
  sources.
* Tue Feb 14 2017 adrien.plazas@suse.com
- Update to version 0.9.90:
  + Merge the retro-gobject module into retro-gtk.
  + Merge the RetroGtk namespace into Retro.
  + Remove many unused types and functions.
  + Refactor many types and functions.
  + Make the API overall simpler.
  + Search modules from their Libretro Core Descriptor.
  + Search Libretro modules in paths from the LIBRETRO_PLUGIN_PATH
    env variable.
  + Drop the ancient module query mechanisms.
  + Drop the ancient Libretro core path env variable.
  + Allow to set a smooth or sharp rendering to CairoDisplay.
- Drop libretro-gobject0 and typelib-1_0-Retro-0_0 subpackage:
  functionality has been merged into the Gtk parts.
- Rename typelib-1_0-RetroGtk-0_8 subpackage to
  typelib-1_0-RetroGtk-0_10, following upstream.
- Add retro-gtk-fix-build-deps.patch which ensures the internal
  header is compiled before the files using it.
* Fri Sep 23 2016 jengelh@inai.de
- Improve the description and summary.
* Wed Sep 21 2016 dimstar@opensuse.org
- Initial package, version 0.8.1.
